@@ -5,10 +5,10 @@ from datetime import datetime
 from urllib.parse import urlparse
 
 import boto3
+import redis
 import requests
 
 from spapi.aws_sig_v4 import AWSSigV4
-from spapi.cache import cache
 from spapi.credential_provider import CredentialProvider
 from spapi.exceptions import SPAPIClientIdNotInWhiteListException, AuthorizationError
 from spapi.lock import RedisLock
@@ -32,7 +32,7 @@ class Client(object):
     def get_url(self):
         return None
 
-    def __init__(self, credentials, max_retries=3, is_grantless=False, region=None, redis_url=None):
+    def __init__(self, credentials, max_retries=3, is_grantless=False, region=None, redis_config=None):
         """
         is_grantless 是否无授权，默认为 False，即需要授权
         """
@@ -42,7 +42,9 @@ class Client(object):
         self.cred = CredentialProvider(credentials=credentials).credentials
         self._validate_client()
         self.is_grantless = is_grantless
-        self.redis_lock = RedisLock([redis_url])
+
+        self.cache = redis.StrictRedis(**redis_config)
+        self.redis_lock = RedisLock(self.cache)
 
     def _validate_client(self):
         """client id 白名单限制"""
@@ -240,14 +242,14 @@ class AmazonSpApi(Client):
         lock_key = key_prefix + '_lock_' + self.cred.refresh_token
 
         while True:
-            data = cache.get(data_key)
+            data = self.cache.get(data_key)
             if not data:
                 locked = self.redis_lock.lock(lock_key, lock_ttl)
                 if locked:
                     try:
                         data = func()
                         print('--------->>> _lock_get_data->data = func()::', data)
-                        cache.setex(data_key, data_ttl, json.dumps(data))
+                        self.cache.setex(data_key, data_ttl, json.dumps(data))
                     finally:
                         self.redis_lock.unlock(locked)
                     return data
